
dialogId("sch-m-spadlo", "font_small", "Something fell here again.")
dialogStr("Hier ist wieder etwas runtergefallen.")


dialogId("sch-v-lastura", "font_big", "It’s some kind of shell. We’ll probably have to push it upstairs again.")
dialogStr("Es ist eine Art Muschel. Wir müssen sie wahrscheinlich wieder die Treppe hochschieben.")


dialogId("sch-v-setkani", "font_big", "I can see it now: 'Shell Meets Flowerpot’. That’s almost like an iron and a sewing machine meeting on an operating table.")
dialogStr("Das ist es: \"Muschel trifft Blumentopf\". Das ist ja fast so, als wenn sich ein Bügeleisen und eine Nähmaschine auf einem Operationstisch treffen.")


dialogId("sch-m-moc0", "font_small", "I’m sorry, I got a bit carried away.")
dialogStr("Tschuldigung, ich habe mich ein wenig mitreißen lassen.")


dialogId("sch-m-moc1", "font_small", "Sorry, I was momentarily distracted.")
dialogStr("Tschuldigung, ich war für einen Moment abgelenkt.")


dialogId("sch-m-moc2", "font_small", "Where I am going with this shell?")
dialogStr("Wohin soll ich mit der Muschel?")

